@@ -1,4 +1,4 @@
-from . import dataset, metrics, trainers, models, zenodo, plotting, utils
+from . import dataset, metrics, trainers, models, zenodo, plotting, utils, classifiers
 
 __author__ = ', '.join([
     'Marco Wagenstetter',
@@ -14,4 +14,4 @@ __email__ = ', '.join([
     'sergei.rybakov@helmholtz-muenchen.de'
 ])
 
-__version__ = '0.5.0'
+__version__ = '0.5.4'
