@@ -1,6 +1,5 @@
 from .trvae._utils import label_encoder
 from .trvae.data_handling import remove_sparsity
-from scvi.data import setup_anndata
 from .trvae.anndata import AnnotatedDataset as trVAEDataset
 
-__all__ = ('label_encoder', 'remove_sparsity', 'setup_anndata', 'trVAEDataset')
+__all__ = ('label_encoder', 'remove_sparsity', 'trVAEDataset')
